# cupp
> Common User Password Profiler

-----

## Description
**CUPP** (Common User Password Profile) is a tool to generate target specific wordlists based on their details provided.

## Version
**Cupp v1.2.9**

## Installation

### Using PIP3
- Create a new Python Virtual Environment
	```bash
	python3 -m venv env
	```
- Activate the virtualenv
	```bash
	source env/bin/activate
	```
- Install and run the tool
	```bash
	pip3 install -e . && cupp -v
	```
- Onliner
	```bash
	python3 -m venv && source env/bin/activate && pip3 install -e . && cupp -v
	```


### Using this repo
- Git clone the respository
	```bash
	git clone https://github.com/thehackersbrain/cupp.git
	```
- Change the directory to `cupp`
	```bash
	cd cupp
	```
- Create new python virtualenv and activate it
	```bash
	python3 -m venv env && source env/bin/activate
	```
- Install the tool using **`pip3`**
	```bash
	pip3 install -e .
	```
- Oneliner
	```bash
	git clone https://github.com/thehackersbrain/cupp.git && cd cupp && python3 -m venv env && source env/bin/activate && pip3 install -e . && cupp -v
	```


## Screenshots
![https://raw.githubusercontent.com/thehackersbrain/cupp/main/screenshots/Pasted image 20220501112100.png]
![https://raw.githubusercontent.com/thehackersbrain/cupp/main/screenshots/Pasted image 20220501113616.png]
![https://raw.githubusercontent.com/thehackersbrain/cupp/main/screenshots/demo.gif]

## Credit
This tool is originally designed by [**Mebus**](https://github.com/Mebus) [here](https://github.com/Mebus/cupp.git). I tried to enhance the **UI** and added some functionality than the previous version and removed some redundant code, basically it's a mess **;)**

## Social Handles
- [Portfolio](https://gauravraj.xyz/)
- [Blog](https://blog.gauravraj.xyz/)
- [Github](https://github.com/thehackersbrain)
- [Twitter](https://twitter.com/thehackersbrain)
- [LinkedIn](https://www.linkedin.com/in/thehackersbrain)
- [Instagram](https://instagram.com/thehackersbrain)
- [More Projects](https://github.com/thehackersbrain?tab=repositories)